------------------------------------------------------------------------
-- Copyright Notice:                                                    
-- (c) Copyright 2004, National Optical Astronomy Observatory, which is 
-- operated for the National Science Foundation by the Association of   
-- Universities for Research in Astronomy under Cooperative Agreement   
-- No. AST-0132798.                                                     
--                                                                      
------------------------------------------------------------------------
-- PROJECT      :   MONSOON
-- BOARD        :   GENERIC
-- DEVICE ID    :   U22 (IR ACQ FPGA)
-- PARENT MODULE:   SEQUENCER TOP LEVEL (SEQ_FPGA)  
-- MODULE       :   Loop Counter Stack 
-- VERSION      :   1.0 
------------------------------------------------------------------------
-- FILE NAME    :   Loop_Count_Stack.VHD
-- AUTHOR       :   KAVIRAJ CHOPRA
-- DATE         :   02/22/2003
-- COMPANY      :   NOAO
-- PLATFORM     :   Xilinx ISE 4.2
------------------------------------------------------------------------
-- DESCRIPTION  :   
-- The module is a simple 16 bit x 16 word RAM. Functions as a Loop
-- Counnter Stack to store the Loop Counts inorder to facilitate 
-- the nested LOOP structures.  
------------------------------------------------------------------------
-- IMPLEMENTATION NOTES :
-- The module will be implemented as a distributed RAM, 
-- The current depth of  the RAM is 16 words however it can be furhter
-- increased as and when needed.
------------------------------------------------------------------------
-- REVISION HISTORY :
-- DATE	  AUTHOR  VERSION  MODIFICATIONS
--
------------------------------------------------------------------------
-- PORT DEFINITIONS 	:
-- LCSPtr : Memory address 4 bits :- 16 words
-- LCSWriteData : Write port : 16 bit 
-- LCSWrite : Write Strobe
-- LCSRdData : Read Port : 16 bit
-- SysClk : System Clock 40 MHz.
------------------------------------------------------------------------


library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity Loop_Count_Stack is
    Port ( LCSPtr : in std_logic_vector(5 downto 0);
           LCSWriteData : in std_logic_vector(15 downto 0);
           LcsWrite : in std_logic;
           LCSRdData : out std_logic_vector(15 downto 0);
		   SysClk	: in std_logic);
end Loop_Count_Stack;

architecture Behavioral of Loop_Count_Stack is

 type ram_type is array (63 downto 0) of std_logic_vector (15 downto 0); 
 signal RAM : ram_type; 

begin

 process (SysClk) 
 begin 
 	if rising_edge (SysClk) then  
 		if (LCSWrite = '1') then 
 			RAM(conv_integer(LCSPtr)) <= LCSWriteData; 
 		end if; 
 	end if; 
 end process;
 
 LCSRDData <= RAM(conv_integer(LCSPtr)); 

end Behavioral;

