------------------------------------------------------------------------
-- Copyright Notice:                                                    
-- (c) Copyright 2004, National Optical Astronomy Observatory, which is 
-- operated for the National Science Foundation by the Association of   
-- Universities for Research in Astronomy under Cooperative Agreement   
-- No. AST-0132798.                                                     
--                                                                      
------------------------------------------------------------------------
-- PROJECT      :   MONSOON
-- BOARD        :   GENERIC
-- DEVICE ID    :   U22 (IR ACQ FPGA)
-- PARENT MODULE:   SEQUENCER TOP LEVEL (SEQ_FPGA)  
-- MODULE       :   Pattern Pointer Stack 
-- VERSION      :   4.2 
------------------------------------------------------------------------
-- FILE NAME    :   Address_Stack.VHD
-- AUTHOR       :   PETER MOORE
-- DATE         :   05/13/2004
-- COMPANY      :   NOAO
-- PLATFORM     :   Xilinx ISE 5.2
------------------------------------------------------------------------
-- DESCRIPTION  :   
-- The module is a simple 11 bit wide x 64 word deep RAM. Functions as a Pattern
-- Pointer Stack to facilitate the CALL and RET instruction implementation.
------------------------------------------------------------------------
-- IMPLEMENTATION NOTES :
-- The module will be implemented as a distributed RAM, 
-- The current depth of  the RAM is 64 words however it can be
-- increased as and when needed.
------------------------------------------------------------------------
-- REVISION HISTORY :
-- DATE	      AUTHOR  VERSION  MODIFICATIONS
-- 05/13/2004  PCM     4.2     initial version ... Copy of Address Stack.
------------------------------------------------------------------------
-- PORT DEFINITIONS 	:
-- AddrPtr      : Memory Address 6 bits :- 64 words
-- PatWriteData : Write port <= 11 bit 
-- PatWrite     : Write Strobe
-- PatReadData  : Read Port => 11 bit
-- SysClk	    : System Clock 40 MHz.
------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity Pattern_Stack is
    Port ( AddrPtr      : in std_logic_vector(5 downto 0);
           PatWriteData : in std_logic_vector(10 downto 0);
           PatWrite     : in std_logic;
           PatReadData  : out std_logic_vector(10 downto 0);
		   SysClk	    : in std_logic
         );
end Pattern_Stack;

architecture Behavioral of Pattern_Stack is
 type ram_type is array (63 downto 0) of std_logic_vector (10 downto 0); 
 signal RAM : ram_type; 

begin

 process (SysClk) 
 begin 
 	if rising_edge (SysClk) then  
 		if (PatWrite = '1') then 
 			RAM(conv_integer(AddrPtr)) <= PatWriteData; 
 		end if; 
 	end if; 
 end process;
 
 PatReadData <= RAM(conv_integer(AddrPtr)); 

 end Behavioral;
