------------------------------------------------------------------------
-- Copyright Notice:
-- (c) Copyright 2004 - 2008, National Optical Astronomy Observatory,
-- which is operated for the National Science Foundation by the
-- Association of Universities for Research in Astronomy under
-- Cooperative Agreement No. AST-0132798.
------------------------------------------------------------------------
-- PROJECT      :   MONSOON-TORRENT
-- BOARD        :   LOCAL CONTROL BOARD
-- DEVICE ID    :   VIRTEX 5LX
-- PARENT MODULE:   CFG_SERVICES
-- MODULE       :   TEMPERATURE MUX
-- VERSION      :   1.02
------------------------------------------------------------------------
-- FILE NAME    :   TempMux_V102.vhd
-- AUTHOR       :   Peter Moore
-- DATE         :   02/04/2010
-- COMPANY      :   NOAO
-- PLATFORM     :   Xilinx ISE 10.1.03
------------------------------------------------------------------------
-- DESCRIPTION  :  Provides a simpel multiplexor to output the current tempertaure
--                 values to the PSM module. These are used to select the DHE temp
--                 servo feedback source.
--              
------------------------------------------------------------------------
-- IMPLEMENTATION NOTES :
--  DheTempSensorSlct_reg 
--                  Value                                   Sensor Selected for servo reference
--                  "000"                                   fpgaTemp (From system monitor)
--                  "001"                                   LCB_temperature0  (From CFG module)
--                  "010"                                   LCB_temperature1  (From CFG module)
--                  "011"                                   AFE0_temperature  (From CFG module)
--                  "100"                                  AFE0_temperature1  (From CFG module)
--                  "101"                                   AFE1_temperature0  (From CFG module)
--                  "110"                                   AFE1_temperature1  (From CFG module)
--                  "111"                                    Manual seting from PAN (for testing purposes)

------------------------------------------------------------------------
-- REVISION HISTORY :
-- DATE	     AUTHOR  VERSION  MODIFICATIONS
-- 02/04/2010  PCM     1.02    INITIAL VERSION
--
------------------------------------------------------------------------
-- PORT DEFINITIONS :
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

entity TempMux_V102 is
	Port (
-- Temperature selector Control signal
      TempChanSlct_i       : in   std_logic_vector(2 downto 0);
-- Temperature value inputs
      LCB_temperature0_i   : in   std_logic_vector(11 downto 0);
      LCB_temperature1_i   : in   std_logic_vector(11 downto 0);
      AFE1_temperature0_i  : in   std_logic_vector(11 downto 0);
      AFE1_temperature1_i  : in   std_logic_vector(11 downto 0);
      AFE2_temperature0_i  : in   std_logic_vector(11 downto 0);
      AFE2_temperature1_i  : in   std_logic_vector(11 downto 0);
-- Temperature Mux output      
      Temperature_o        : out  std_logic_vector(11 downto 0)   
      );
end TempMux_V102;

architecture Behavioral of TempMux_V102 is
begin

   TempMuxProc : process(TempChanSlct_i, LCB_temperature0_i, LCB_temperature1_i, AFE1_temperature0_i, AFE1_temperature1_i, AFE2_temperature0_i, AFE2_temperature1_i)
   begin
      case TempChanSlct_i is
         when "001" =>
            Temperature_o <= LCB_temperature0_i;
         when "010" =>
            Temperature_o <= LCB_temperature1_i;         
         when "011" =>
            Temperature_o <= AFE1_temperature0_i;
         when "100" =>
            Temperature_o <= AFE1_temperature1_i;
         when "101" =>
            Temperature_o <= AFE2_temperature0_i;
         when "110" =>
            Temperature_o <= AFE2_temperature1_i;
         when others =>    
            Temperature_o <= (others => '0');
      end case;
   end process;

end Behavioral;

